@@ -316,5 +316,5 @@ def get_function_definitions_list(function_signatures):
         for signature in function_signatures:
             definition_list.append(signature_to_function(signature))
     except:
-        print('Function Signature Database not Avaliable.')
+        difinition_list = ['Function Signature Database not Avaliable.']
     return definition_list
\ No newline at end of file
